# ProtWaveVAE_model
A fully featured autoregressive (AR) Variational autoencoder (VAE) using a WaveNet decoder for data-driven protein design (ProtWave-VAE).


![ProtWave-VAE architecture and applications](Figure1.png)


